@@ -93,3 +93,14 @@ class DummyCloudConnector(CloudConnector):
 
     def delete_image(self, image_url, auth_data):
         return (True, "")
+
+    def list_images(self, auth_data, filters=None):
+        return [{"uri": "mock0://linux.for.ev.er/image1", "name": "Image Name1"},
+                {"uri": "mock0://linux.for.ev.er/image2", "name": "Image Name2"}]
+
+    def get_quotas(self, auth_data):
+        return {"cores": {"used": 1, "limit": 10},
+                "ram": {"used": 1, "limit": 10},
+                "instances": {"used": 1, "limit": 10},
+                "floating_ips": {"used": 1, "limit": 10},
+                "security_groups": {"used": 1, "limit": 10}}
